@@ -149,8 +149,15 @@ class MemberpressEvent(Generic[MemberpressEventChild], Memberpress):
 
     @event.setter
     def event(self, value):
-        if type(value) == str or value is None:
+        if value is None:
             self._event = value
+            return
+
+        if type(value) == str:
+            if value in MemberpressEvents.all():
+                self._event = value
+            else:
+                logger.warning("event() received an unknown event type {value}".format(value=value))
         else:
             logger.warning("was expecting a value of type str but received type {t}".format(t=type(value)))
 
@@ -160,8 +167,15 @@ class MemberpressEvent(Generic[MemberpressEventChild], Memberpress):
 
     @event_type.setter
     def event_type(self, value):
-        if type(value) == str or value is None:
+        if value is None:
             self._event_type = value
+            return
+
+        if type(value) == str:
+            if value in MemberpressEventTypes.all():
+                self._event_type = value
+            else:
+                logger.warning("event_type() received an unknown event type {value}".format(value=value))
         else:
             logger.warning("was expecting a value of type str but received type {t}".format(t=type(value)))
 
